@@ -939,6 +939,7 @@ typedef	shell shell_t;
  * Abusive compilers...
  */
 #undef	_TEXT
+#undef	_STR
 
 /**
  * Invoke translation lookup if available.  This can also be used to
@@ -950,6 +951,9 @@ typedef	shell shell_t;
 inline	const char *_TEXT(const char *s)	
 	{return shell::text(s);}
 
+inline const char *_STR(String& s)
+	{return *s;}
+
 END_NAMESPACE
 
 #endif
